@@ -13,8 +13,10 @@ using namespace Rcpp;
 using namespace arma;
 
 
+
+RcppExport SEXP FastLong2(SEXP idata, SEXP inclust, SEXP infixed, SEXP invarying);
 RcppExport SEXP FastLong(SEXP idata, SEXP inclust, SEXP infixed, SEXP invarying, SEXP missing);
-RcppExport SEXP FastApprox(const SEXP a, const SEXP t, const SEXP z);
+RcppExport SEXP FastApprox(const SEXP time, const SEXP newtime, const SEXP equal);
 RcppExport SEXP FastPattern(SEXP y1,SEXP y2);
 
 void fastpattern(const umat &y, umat &pattern, uvec &group);
